R = 8.31446;
T = 1250 + 273;
P = 450e6;
ndisl = 2.9;                % dimensionless
Adisl = 6.92e8;
Qdisl = -600000             % J/mol
Cdisl = exp(Qdisl./(R*T));
ACdisl = Cdisl*Adisl;

% OPX Diffusion creep parameters (Bruijn and Skemer, 2014)
mdif = -3;                  % Assumed value
d = 8;

Sig = 100:25:500;
logSig = log10(Sig);

%% calculations and plotting for PI-512 @ 1250 C
ACdif = 7.0e-6;             % Variable C that is derived from Lawlis, 1998 experiments.
disstrainrt = ACdisl*Sig.^ndisl;
logdisstrainrt = log10(disstrainrt);
difstrainrt = ACdif*Sig.^1*d.^mdif;
logdifstrainrt = log10(difstrainrt);
totstrainrt = disstrainrt + difstrainrt;
logtotstrainrt = log10(totstrainrt);

lawlis = load('lawlisPI-512_1250.txt');
siga = lawlis(:,1);
PI512_1250 = lawlis(:,2);
discont_a = lawlis(:,3);

figure
plot(logSig,logdisstrainrt,'-r','LineWidth',2)
hold all
plot(logSig,logdifstrainrt,'-g','LineWidth',2)
plot(logSig,logtotstrainrt,'-k','LineWidth',2)
title('PI-512 T = 1250 C, P = 450 MPa, from Lawlis (1998), Cdif = 7.0x10^-^6')
xlabel('Log differential stress (MPa)');
ylabel('Log strainrate (s^{-1})');
axis([2.0 2.7 -7.2 -4.0])
colormap(Jet)
scatter(siga,PI512_1250,50,discont_a,'o','filled')
%plot(siga,PI512_1250,'ok','LineWidth',2)
hleg1 = legend('logdisstrainrt','logdifstrainrt','logtotstrainrt','PI512_-1250');
set(hleg1,'Location','SouthEast')
hold off

%% calculations and plotting for PI-539 @ 1250 C
ACdif = 7.0e-6;             % Variable C that is derived from Lawlis, 1998 experiments.
disstrainrt = ACdisl*Sig.^ndisl;
difstrainrt = ACdif*Sig.^1*d.^mdif;
logdifstrainrt = log10(difstrainrt);
totstrainrt = disstrainrt + difstrainrt;
logtotstrainrt = log10(totstrainrt);

lawlis = load('lawlisPI-539_1250.txt');

siga = lawlis(:,1);
PI539_1250 = lawlis(:,2);
discont_b = lawlis(:,3);

figure
plot(logSig,logdisstrainrt,'-r','LineWidth',2)
hold all
plot(logSig,logdifstrainrt,'-g','LineWidth',2)
plot(logSig,logtotstrainrt,'-k','LineWidth',2)
title('PI-539 T = 1250 C, P = 450 MPa, from Lawlis (1998), Cdif = 7.0x10^-^6')
xlabel('Log differential stress (MPa)');
ylabel('Log strainrate (s^{-1})');
axis([2.0 2.7 -7.2 -4.0])
colormap(Jet)
scatter(siga,PI539_1250,50,discont_b,'o','filled')
hleg1 = legend('logdisstrainrt','logdifstrainrt','logtotstrainrt','PI539_-1250');
set(hleg1,'Location','SouthEast')
hold off

%% calculations and plotting for PI-512 @ 1200 C
T = 1200 + 273;
ACdif = 1.9e-6;            % Variable C that is derived from Lawlis, 1998 experiments.
Cdisl = exp(Qdisl./(R*T));
ACdisl = Cdisl*Adisl;
disstrainrt = ACdisl*Sig.^ndisl;
logdisstrainrt = log10(disstrainrt);
difstrainrt = ACdif*Sig.^1*d.^mdif;
logdifstrainrt = log10(difstrainrt);
totstrainrt = disstrainrt + difstrainrt;
logtotstrainrt = log10(totstrainrt);

lawlis = load('lawlisPI-512_1200.txt');

siga = lawlis(:,2);
PI512_1200 = lawlis(:,4);
discont_c = lawlis(:,5);

figure
plot(logSig,logdisstrainrt,'-r','LineWidth',2)
hold all
plot(logSig,logdifstrainrt,'-g','LineWidth',2)
plot(logSig,logtotstrainrt,'-k','LineWidth',2)
title('PI-512 T = 1200 C, P = 450 MPa, from Lawlis (1998), Cdif = 1.9x10^-^6')
xlabel('Log differential stress (MPa)');
ylabel('Log strainrate (s^{-1})');
axis([2.0 2.7 -7.2 -4.0])
colormap(Jet)
scatter(siga,PI512_1200,50,discont_c,'o','filled')
hleg1 = legend('logdisstrainrt','logdifstrainrt','logtotstrainrt','PI512_-1200');
set(hleg1,'Location','SouthEast')
hold off